@@ -5,6 +5,7 @@ from django.db import IntegrityError
 from flask import request, logging, redirect
 
 from flask.ext import restful
+from werkzeug.exceptions import BadRequest
 
 from pagador import MeioDePagamentoNaoEncontrado, MeioDePagamentoNaoDefinido
 from pagador.configuracao.cadastro import DadosInvalidos
@@ -116,6 +117,10 @@ class PagamentoConfiguracaoBaseResource(restful.Resource):
                 self._dados[arg] = request.args[arg]
             for arg in request.form:
                 self._dados[arg] = request.form[arg]
+            try:
+                self._dados.update(request.get_json())
+            except BadRequest:
+                pass
         return self._dados
 
     @property
