@@ -10,9 +10,11 @@ def normaliza_conteudo_de_resposta(resposta):
             resposta["content"] = {"string": resposta["content"]}
 
 
-def grava_evidencia_envio(meio_pagamento, para, dados, resposta):
+def grava_evidencia_envio(meio_pagamento, para, dados, resposta, conta_id, pedido_numero):
     normaliza_conteudo_de_resposta(resposta)
     evidencia = {
+        "conta_id": conta_id,
+        "pedido_numero": pedido_numero,
         "tipo_evidencia": "pagador-envio",
         "evidencia": {
             "meio_pagamento": meio_pagamento,
