@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
 from pagador import settings
+from pagador.acesso.externo import Conexao
 from pagador.extensao.base import Plugavel, PluginNaoEncontrado
 from pagador.pedido import notificador
 from pagador.retorno.models import PedidoPagamento, Pedido
 from pagador.retorno.notificador import grava_evidencia_retorno
-from pagador.seguranca.autenticador import Conexao, TipoConexao
+from pagador.seguranca.autenticador import TipoConexao
 from pagador.utils import Formatador
 
 
@@ -78,11 +79,11 @@ class RegistrarPagamento(Plugavel):
         if self._conta_id:
             return self._conta_id
         if self.configuracao_pagamento:
-            self._conta_id = self.configuracao_pagamento.conta.id
+            self._conta_id = self.configuracao_pagamento.conta_id
         elif self.registrador.identificador_id:
             try:
                 pedido_pagamento = PedidoPagamento.objects.get(identificador_id=self.registrador.identificador_id)
-                self._conta_id = pedido_pagamento.conta.id
+                self._conta_id = pedido_pagamento.conta_id
             except PedidoPagamento.DoesNotExist, PedidoPagamento.MultipleObjectsReturned:
                 self._conta_id = None
         return self._conta_id
@@ -121,7 +122,7 @@ class RegistrarPagamento(Plugavel):
             tipo_evidencia = "pagador-retorno" if self.tipo == "retorno" else "pagador-redirect"
             enviado = {"status_code": 200}
             enviado.update(resultado)
-            grava_evidencia_retorno(self.meio_pagamento, self.dados, tipo_evidencia=tipo_evidencia, registrado=self.achou_registro, enviado=enviado)
+            grava_evidencia_retorno(self.meio_pagamento, self.dados, self.conta_id, self.registrador.pedido_numero, tipo_evidencia=tipo_evidencia, registrado=self.achou_registro, enviado=enviado)
             resultado["evidencia"] = True
         if self.registrador.redireciona_para:
             return {"redirect": self.registrador.redireciona_para}
