@@ -19,8 +19,14 @@ EVIDENCIA_URL = config.EVIDENCIA_URL
 EVIDENCIA_USA_AUTENTICACAO_HEADER = config.EVIDENCIA_USA_AUTENTICACAO_HEADER
 EVIDENCIA_HEADER_AUTENTICACAO = config.EVIDENCIA_HEADER_AUTENTICACAO
 MODULO_PARAMETROS_INSTALACAO = config.MODULO_PARAMETROS_INSTALACAO
+
 MERCADOPAGO_REDIRECT_URL = config.MERCADOPAGO_REDIRECT_URL
 MERCADOPAGO_PREFERENCE_NOTIFICATION_URL = config.MERCADOPAGO_PREFERENCE_NOTIFICATION_URL
 
-# PAYPAL_NOTIFICATION_URL = config.PAYPAL_NOTIFICATION_URL
-# PAYPAL_VERSION = config.PAYPAL_VERSION
+PAYPAL_NOTIFICATION_URL = config.PAYPAL_NOTIFICATION_URL
+PAYPAL_VERSION = config.PAYPAL_VERSION
+
+PAGSEGURO_REDIRECT_URL = config.PAGSEGURO_REDIRECT_URL
+PAGSEGURO_PREFERENCE_NOTIFICATION_URL = config.PAGSEGURO_PREFERENCE_NOTIFICATION_URL
+
+BCASH_NOTIFICATION_URL = config.BCASH_NOTIFICATION_URL
